==> dosbox-x-0.83.24.tar.gz: dosbox-x-dosbox-x-v0.83.24/vs/sdl/include/SDL_syswm.h <==
/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2012 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Sam Lantinga
    slouken@libsdl.org
*/

/** @file SDL_syswm.h
 *  Include file for SDL custom system window manager hooks
 */

#ifndef _SDL_syswm_h
#define _SDL_syswm_h

#include "SDL_stdinc.h"
#include "SDL_error.h"
#include "SDL_version.h"

//#include "begin_code.h"
/* Set up for C function definitions, even when using C++ */
#ifdef __cplusplus
extern "C" {
#endif

/** @file SDL_syswm.h
 *  Your application has access to a special type of event 'SDL_SYSWMEVENT',
 *  which contains window-manager specific information and arrives whenever
 *  an unhandled window event occurs.  This event is ignored by default, but
 *  you can enable it with SDL_EventState()
 */
#ifdef SDL_PROTOTYPES_ONLY
struct SDL_SysWMinfo;
typedef struct SDL_SysWMinfo SDL_SysWMinfo;

struct SDL_SysIMinfo;
typedef struct SDL_SysIMinfo SDL_SysIMinfo;
#else

/* This is the structure for custom window manager events */
#if defined(SDL_VIDEO_DRIVER_X11)
#if defined(__APPLE__) && defined(__MACH__)
/* conflicts with Quickdraw.h */
#define Cursor X11Cursor
#endif

#include <X11/Xlib.h>
#include <X11/Xatom.h>

#if defined(__APPLE__) && defined(__MACH__)
/* matches the re-define above */
#undef Cursor
#endif

/** These are the various supported subsystems under UNIX */
typedef enum {
	SDL_SYSWM_X11
} SDL_SYSWM_TYPE;

/** The UNIX custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	SDL_SYSWM_TYPE subsystem;
	union {
	    XEvent xevent;
	} event;
};

/** The UNIX custom window manager information structure.
 *  When this structure is returned, it holds information about which
 *  low level system it is using, and will be one of SDL_SYSWM_TYPE.
 */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	SDL_SYSWM_TYPE subsystem;
	union {
	    struct {
	    	Display *display;	/**< The X11 display */
	    	Window window;		/**< The X11 display window */
		/** These locking functions should be called around
                 *  any X11 functions using the display variable, 
                 *  but not the gfxdisplay variable.
                 *  They lock the event thread, so should not be
		 *  called around event functions or from event filters.
		 */
                /*@{*/
		void (*lock_func)(void);
		void (*unlock_func)(void);
                /*@}*/

		/** @name Introduced in SDL 1.0.2 */
                /*@{*/
	    	Window fswindow;	/**< The X11 fullscreen window */
	    	Window wmwindow;	/**< The X11 managed input window */
                /*@}*/

		/** @name Introduced in SDL 1.2.12 */
                /*@{*/
		Display *gfxdisplay;	/**< The X11 display to which rendering is done */
                /*@}*/
	    } x11;
	} info;
} SDL_SysWMinfo;

/* The UNIX custom input method information structure */
typedef struct SDL_SysIMinfo {
	SDL_version version;
	XIM xim;			/* The X11 input mathod */
	XIC *xic;			/* The X11 input mathod context */
} SDL_SysIMinfo;

#elif defined(SDL_VIDEO_DRIVER_NANOX)
#include <microwin/nano-X.h>

/** The generic custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/** The windows custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version ;
	GR_WINDOW_ID window ;	/* The display window */
} SDL_SysWMinfo;

#elif defined(SDL_VIDEO_DRIVER_WINDIB) || defined(SDL_VIDEO_DRIVER_DDRAW) || defined(SDL_VIDEO_DRIVER_GAPI)
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

/** The windows custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	HWND hwnd;			/**< The window for the message */
	UINT msg;			/**< The type of message */
	WPARAM wParam;			/**< WORD message parameter */
	LPARAM lParam;			/**< LONG message parameter */
};

/** The windows custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	HWND window;			/**< The Win32 display window */
	HWND child_window;		/**< The Win32 surface window (generally, child of window) */
	HGLRC hglrc;			/**< The OpenGL context, if any */
} SDL_SysWMinfo;

#if !defined(__MINGW32__) || defined(__MINGW64_VERSION_MAJOR)
/* The windows custom input method information structure */
typedef struct SDL_SysIMinfo {
	SDL_version version;
	HWND ime;				/* The Win32 input method window */
	HIMC imc;				/* The Win32 input method context */
	union {
		struct {
			void **notify_data;
			void (**notify_func)(void*);
		} win;
	} info;
} SDL_SysIMinfo;
#endif

#elif defined(SDL_VIDEO_DRIVER_RISCOS)

/** RISC OS custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int eventCode;		/**< The window for the message */
	int pollBlock[64];
};

/** The RISC OS custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	int wimpVersion;    /**< Wimp version running under */
	int taskHandle;     /**< The RISC OS task handle */
	int window;		/**< The RISC OS display window */
} SDL_SysWMinfo;

#elif defined(SDL_VIDEO_DRIVER_PHOTON)
#include <sys/neutrino.h>
#include <Ph.h>

/** The QNX custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/** The QNX custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	int data;
} SDL_SysWMinfo;

#else

/** The generic custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/** The generic custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	int data;
} SDL_SysWMinfo;

#endif /* video driver type */

#endif /* SDL_PROTOTYPES_ONLY */

/* Function prototypes */
/**
 * This function gives you custom hooks into the window manager information.
 * It fills the structure pointed to by 'info' with custom information and
 * returns 0 if the function is not implemented, 1 if the function is 
 * implemented and no error occurred, and -1 if the version member of
 * the 'info' structure is not filled in or not supported.
 *
 * You typically use this function like this:
 * @code
 * SDL_SysWMinfo info;
 * SDL_VERSION(&info.version);
 * if ( SDL_GetWMInfo(&info) ) { ... }
 * @endcode
 */
extern DECLSPEC int SDLCALL SDL_GetWMInfo(SDL_SysWMinfo *info);

#ifdef ENABLE_IM_EVENT
/* This function gives you custom hooks into the input method information. */
extern DECLSPEC int SDLCALL SDL_GetIMInfo(SDL_SysIMinfo *info);
#endif

/* Ends C function definitions when using C++ */
#ifdef __cplusplus
}
#endif
//#include "close_code.h"

#endif /* _SDL_syswm_h */

==> dosbox-x-0.84.3.tar.gz: dosbox-x-dosbox-x-v0.84.3/vs/sdl/include/SDL_syswm.h <==
/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2012 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Sam Lantinga
    slouken@libsdl.org
*/

/** @file SDL_syswm.h
 *  Include file for SDL custom system window manager hooks
 */

#ifndef _SDL_syswm_h
#define _SDL_syswm_h

#include "SDL_stdinc.h"
#include "SDL_error.h"
#include "SDL_version.h"

//#include "begin_code.h"
/* Set up for C function definitions, even when using C++ */
#ifdef __cplusplus
extern "C" {
#endif

#if defined(__MINGW32__) && !defined(SDL_WIN32_HX_DOS)
#include <windows.h>
#include <imm.h>
#endif

/** @file SDL_syswm.h
 *  Your application has access to a special type of event 'SDL_SYSWMEVENT',
 *  which contains window-manager specific information and arrives whenever
 *  an unhandled window event occurs.  This event is ignored by default, but
 *  you can enable it with SDL_EventState()
 */
#ifdef SDL_PROTOTYPES_ONLY
struct SDL_SysWMinfo;
typedef struct SDL_SysWMinfo SDL_SysWMinfo;

struct SDL_SysIMinfo;
typedef struct SDL_SysIMinfo SDL_SysIMinfo;
#else

/* This is the structure for custom window manager events */
#if defined(SDL_VIDEO_DRIVER_X11)
#if defined(__APPLE__) && defined(__MACH__)
/* conflicts with Quickdraw.h */
#define Cursor X11Cursor
#endif

#include <X11/Xlib.h>
#include <X11/Xatom.h>

#if defined(__APPLE__) && defined(__MACH__)
/* matches the re-define above */
#undef Cursor
#endif

/** These are the various supported subsystems under UNIX */
typedef enum {
	SDL_SYSWM_X11
} SDL_SYSWM_TYPE;

/** The UNIX custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	SDL_SYSWM_TYPE subsystem;
	union {
	    XEvent xevent;
	} event;
};

/** The UNIX custom window manager information structure.
 *  When this structure is returned, it holds information about which
 *  low level system it is using, and will be one of SDL_SYSWM_TYPE.
 */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	SDL_SYSWM_TYPE subsystem;
	union {
	    struct {
	    	Display *display;	/**< The X11 display */
	    	Window window;		/**< The X11 display window */
		/** These locking functions should be called around
                 *  any X11 functions using the display variable, 
                 *  but not the gfxdisplay variable.
                 *  They lock the event thread, so should not be
		 *  called around event functions or from event filters.
		 */
                /*@{*/
		void (*lock_func)(void);
		void (*unlock_func)(void);
                /*@}*/

		/** @name Introduced in SDL 1.0.2 */
                /*@{*/
	    	Window fswindow;	/**< The X11 fullscreen window */
	    	Window wmwindow;	/**< The X11 managed input window */
                /*@}*/

		/** @name Introduced in SDL 1.2.12 */
                /*@{*/
		Display *gfxdisplay;	/**< The X11 display to which rendering is done */
                /*@}*/
	    } x11;
	} info;
} SDL_SysWMinfo;

/* The UNIX custom input method information structure */
typedef struct SDL_SysIMinfo {
	SDL_version version;
	XIM xim;			/* The X11 input mathod */
	XIC *xic;			/* The X11 input mathod context */
} SDL_SysIMinfo;

#elif defined(SDL_VIDEO_DRIVER_NANOX)
#include <microwin/nano-X.h>

/** The generic custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/** The windows custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version ;
	GR_WINDOW_ID window ;	/* The display window */
} SDL_SysWMinfo;

#elif defined(SDL_VIDEO_DRIVER_WINDIB) || defined(SDL_VIDEO_DRIVER_DDRAW) || defined(SDL_VIDEO_DRIVER_GAPI)
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

/** The windows custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	HWND hwnd;			/**< The window for the message */
	UINT msg;			/**< The type of message */
	WPARAM wParam;			/**< WORD message parameter */
	LPARAM lParam;			/**< LONG message parameter */
};

/** The windows custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	HWND window;			/**< The Win32 display window */
	HWND child_window;		/**< The Win32 surface window (generally, child of window) */
	HGLRC hglrc;			/**< The OpenGL context, if any */
} SDL_SysWMinfo;

#if !defined(SDL_WIN32_HX_DOS)
/* The windows custom input method information structure */
typedef struct SDL_SysIMinfo {
	SDL_version version;
	HWND ime;				/* The Win32 input method window */
	HIMC imc;				/* The Win32 input method context */
	union {
		struct {
			void **notify_data;
			void (**notify_func)(void*);
		} win;
	} info;
} SDL_SysIMinfo;
#endif

#elif defined(SDL_VIDEO_DRIVER_RISCOS)

/** RISC OS custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int eventCode;		/**< The window for the message */
	int pollBlock[64];
};

/** The RISC OS custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	int wimpVersion;    /**< Wimp version running under */
	int taskHandle;     /**< The RISC OS task handle */
	int window;		/**< The RISC OS display window */
} SDL_SysWMinfo;

#elif defined(SDL_VIDEO_DRIVER_PHOTON)
#include <sys/neutrino.h>
#include <Ph.h>

/** The QNX custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/** The QNX custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	int data;
} SDL_SysWMinfo;

#else

/** The generic custom event structure */
struct SDL_SysWMmsg {
	SDL_version version;
	int data;
};

/** The generic custom window manager information structure */
typedef struct SDL_SysWMinfo {
	SDL_version version;
	int data;
} SDL_SysWMinfo;

#endif /* video driver type */

#endif /* SDL_PROTOTYPES_ONLY */

/* Function prototypes */
/**
 * This function gives you custom hooks into the window manager information.
 * It fills the structure pointed to by 'info' with custom information and
 * returns 0 if the function is not implemented, 1 if the function is 
 * implemented and no error occurred, and -1 if the version member of
 * the 'info' structure is not filled in or not supported.
 *
 * You typically use this function like this:
 * @code
 * SDL_SysWMinfo info;
 * SDL_VERSION(&info.version);
 * if ( SDL_GetWMInfo(&info) ) { ... }
 * @endcode
 */
extern DECLSPEC int SDLCALL SDL_GetWMInfo(SDL_SysWMinfo *info);

#ifdef ENABLE_IM_EVENT
/* This function gives you custom hooks into the input method information. */
extern DECLSPEC int SDLCALL SDL_GetIMInfo(SDL_SysIMinfo *info);
#endif

/* Ends C function definitions when using C++ */
#ifdef __cplusplus
}
#endif
//#include "close_code.h"

#endif /* _SDL_syswm_h */
